@@ -1,12 +1,12 @@
-#line 1 "inc/ExtUtils/AutoInstall.pm - /usr/local/lib/perl5/site_perl/5.8.5/ExtUtils/AutoInstall.pm"
+#line 1 "inc/ExtUtils/AutoInstall.pm - /usr/local/lib/perl5/site_perl/5.8.7/ExtUtils/AutoInstall.pm"
 package ExtUtils::AutoInstall;
-$ExtUtils::AutoInstall::VERSION = '0.61';
+$ExtUtils::AutoInstall::VERSION = '0.63';
 
 use strict;
 use Cwd ();
 use ExtUtils::MakeMaker ();
 
-#line 305
+#line 312
 
 # special map on pre-defined feature sets
 my %FeatureMap = (
@@ -354,8 +354,10 @@ sub _install_cpan {
     my %args;
 
     require CPAN; CPAN::Config->load;
+    require Config;
 
-    return unless _can_write(MM->catfile($CPAN::Config->{cpan_home}, 'sources'));
+    return unless _can_write(MM->catfile($CPAN::Config->{cpan_home}, 'sources'))
+              and _can_write($Config::Config{sitelib});
 
     # if we're root, set UNINST=1 to avoid trouble unless user asked for it.
     my $makeflags = $CPAN::Config->{make_install_arg} || '';
@@ -485,8 +487,7 @@ sub _can_write {
     my $path = shift;
     mkdir ($path, 0755) unless -e $path;
 
-    require Config;
-    return 1 if -w $path and -w $Config::Config{sitelib};
+    return 1 if -w $path;
 
     print << ".";
 *** You are not allowed to write to the directory '$path';
@@ -643,4 +644,4 @@ installdeps ::
 
 __END__
 
-#line 970
+#line 978
