@@ -1,9 +1,5 @@
 #undef PL_statbuf
 #undef readdir
-#ifdef WIN32
-#  include <process.h>
-#  define mkdir(file, mode) _mkdir(file)
-#endif
 
 #include "mktmpdir.c"
 #include "my_perl.c"
@@ -62,7 +58,7 @@ typedef BOOL (WINAPI *pALLOW)(DWORD);
 
     stmpdir = (char *)par_getenv("PAR_TEMP");
     if ( stmpdir != NULL ) {
-        i = mkdir(stmpdir, 0755);
+        i = my_mkdir(stmpdir, 0755);
         if ( (i != 0) && (i != EEXIST) && (i != -1) ) {
             fprintf(stderr, "%s: creation of private temporary subdirectory %s failed - aborting with %i.\n", argv[0], stmpdir, errno);
             return 2;
